Decoder

Struct Decoder 

pub struct Decoder<'de, 'state> { /* private fields */ }
The Decoder wraps a byte slice with necessary info to progressively deserialize the bytes into a sequence of tokens.

Usage Note

While the Decoder contains the necessary info, the actual deserialization is done in the crate::SolType trait.

Implementations

Source

impl<'de> Decoder<'de, 'static>

pub const fn new(buf: &'de [u8]) -> Self

Instantiates a new decoder from a byte slice.

Source

impl<'de, 'state> Decoder<'de, 'state>

pub const fn offset(&self) -> usize

Returns the current offset in the buffer.

pub const fn remaining(&self) -> Option<usize>

Returns the number of bytes in the remaining buffer.

pub const fn remaining_words(&self) -> usize

Returns the number of words in the remaining buffer.

pub fn remaining_buf(&self) -> Option<&'de [u8]>

Returns a reference to the remaining bytes in the buffer.

pub const fn is_empty(&self) -> bool

Returns whether the remaining buffer is empty.

pub fn raw_child<'child>(&'child self) -> Result<Decoder<'de, 'child>>

Create a child decoder, starting at offset bytes from the current decoder’s offset.

See child.

pub fn child<'child>( &'child self, offset: usize, ) -> Result<Decoder<'de, 'child>, Error>

Create a child decoder, starting at offset bytes from the current decoder’s offset. The child decoder shares the buffer.

pub fn peek<I: SliceIndex<[u8]>>( &self, index: I, ) -> Result<&'de I::Output, Error>

Peek into the buffer.

pub fn peek_len_at(&self, offset: usize, len: usize) -> Result<&'de [u8], Error>

Peek a slice of size len from the buffer at a specific offset, without advancing the offset.

pub fn peek_len(&self, len: usize) -> Result<&'de [u8], Error>

Peek a slice of size len from the buffer without advancing the offset.

pub fn peek_word_at(&self, offset: usize) -> Result<&'de Word, Error>

Peek a word from the buffer at a specific offset, without advancing the offset.

pub fn peek_word(&self) -> Result<&'de Word, Error>

Peek the next word from the buffer without advancing the offset.

pub fn peek_offset_at(&self, offset: usize) -> Result<usize>

Peek a usize from the buffer at a specific offset, without advancing the offset.

pub fn peek_offset(&self) -> Result<usize>

Peek a usize from the buffer, without advancing the offset.

pub fn take_word(&mut self) -> Result<&'de Word, Error>

Take a word from the buffer, advancing the offset.

pub fn take_indirection<'child>( &'child mut self, ) -> Result<Decoder<'de, 'child>, Error>

Return a child decoder by consuming a word, interpreting it as a pointer, and following it.

pub fn take_offset(&mut self) -> Result<usize>

Takes a usize offset from the buffer by consuming a word.

pub fn take_slice(&mut self, len: usize) -> Result<&'de [u8]>

Takes a slice of bytes of the given length.

pub const fn take_offset_from(&mut self, child: &Decoder<'de, '_>)

Takes the offset from the child decoder and sets it as the current offset.

pub const fn offset_from_child(&self, child: &Decoder<'de, '_>) -> usize

Returns the parent-relative offset from a child decoder.

pub const fn set_offset(&mut self, offset: usize)

Sets the current offset in the buffer.

pub fn decode<T: Token<'de>>(&mut self) -> Result<T>

Decodes a single token from the underlying buffer.

pub fn decode_sequence<T: Token<'de> + TokenSeq<'de>>(&mut self) -> Result<T>

Decodes a sequence of tokens from the underlying buffer.